==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/de-DE/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Zubehör zurückgenommen',
    'Accessory_Checkout_Notification' => 'Zubehör herausgegeben',
    'Asset_Checkin_Notification' => 'Asset zurückgenommen',
    'Asset_Checkout_Notification' => 'Asset herausgegeben',
    'Confirm_Accessory_Checkin' => 'Bestätigung einer Zubehör Rücknahme',
    'Confirm_Asset_Checkin' => 'Bestätigung einer Asset Rücknahme',
    'Confirm_accessory_delivery' => 'Bestätigung einer Zubehör Herausgabe',
    'Confirm_asset_delivery' => 'Bestätigung einer Asset Herausgabe',
    'Confirm_consumable_delivery' => 'Bestätigung einer Verbrauchsmaterial Herausgabe',
    'Confirm_license_delivery' => 'Bestätigung einer Lizenz Herausgabe',
    'Consumable_checkout_notification' => 'Verbrauchsmaterial herausgegeben',
    'Days' => 'Tage',
    'Expected_Checkin_Date' => 'Ihr ausgebuchtes Asset ist fällig zur Rückgabe am :date',
    'Expected_Checkin_Notification' => 'Erinnerung: :name Rückgabedatum nähert sich',
    'Expected_Checkin_Report' => 'Bericht über erwartete Asset Rückgaben',
    'Expiring_Assets_Report' => 'Bericht über ablaufende Gegenstände.',
    'Expiring_Licenses_Report' => 'Bericht über ablaufende Lizenzen.',
    'Item_Request_Canceled' => 'Gegenstands Anfrage abgebrochen',
    'Item_Requested' => 'Gegenstand angefordert',
    'License_Checkin_Notification' => 'Lizenz zurückgenommen',
    'License_Checkout_Notification' => 'Lizenz herausgegeben',
    'Low_Inventory_Report' => 'Bericht über niedrige Lagerbestände',
    'a_user_canceled' => 'Eine Geräte-Anfrage auf der Webseite wurde vom Benutzer abgebrochen',
    'a_user_requested' => 'Ein Benutzer hat ein Gerät auf der Webseite angefordert',
    'acceptance_asset_accepted' => 'Ein Benutzer hat einen Gegenstand akzeptiert',
    'acceptance_asset_declined' => 'Ein Benutzer hat einen Gegenstand abgelehnt',
    'accessory_name' => 'Zubehör Name:',
    'additional_notes' => 'Zusätzliche Bemerkungen:',
    'admin_has_created' => 'Ein Administrator hat auf der :web Webseite ein Konto für Sie erstellt.',
    'asset' => 'Asset:',
    'asset_name' => 'Name des Gegenstandes:',
    'asset_requested' => 'Gegenstand angefordert',
    'asset_tag' => 'Asset Tag',
    'assets_warrantee_alert' => 'Die Garantie von :count Asset wird in :threshold Tagen auslaufen.|Die Garantie von :count Assets wird in :threshold Tagen auslaufen.',
    'assigned_to' => 'Zugewiesen an',
    'best_regards' => 'Grüße,',
    'canceled' => 'Abgebrochen:',
    'checkin_date' => 'Rücknahmedatum:',
    'checkout_date' => 'Herausgabedatum:',
    'checkedout_from' => 'Herausgegeben von',
    'checkedin_from'  => 'Eingecheckt von',
    'checked_into' => 'Zurückgenommen in',
    'click_on_the_link_accessory' => 'Bitte klicken Sie auf den Link weiter unten, um den Erhalt des Zubehörs zu bestätigen.',
    'click_on_the_link_asset' => 'Bitte klicken Sie auf den Link weiter unten, um den Erhalt des Gegenstands zu bestätigen.',
    'click_to_confirm' => 'Bitte klicken Sie zum Bestätigen Ihres :web Kontos auf den folgenden Link:',
    'current_QTY' => 'Aktuelle Menge',
    'days' => 'Tage',
    'expecting_checkin_date' => 'Erwartetes Rückgabedatum:',
    'expires' => 'Ablaufdatum',
    'hello' => 'Hallo',
    'hi' => 'Hallo',
    'i_have_read' => 'Ich habe die Nutzungsbedingungen gelesen und stimme diesen zu, und ich habe diesen Gegenstand erhalten.',
    'inventory_report' => 'Bestandsbericht',
    'item' => 'Gegenstand:',
    'item_checked_reminder' => 'Dies ist eine Erinnerung daran, dass Sie derzeit :count Artikel ausgeliehen haben, die Sie weder angenommen noch abgelehnt haben. Klicken Sie bitte auf den untenstehenden Link, um diese entweder anzunehmen oder abzulehnen.',
    'license_expiring_alert' => 'Es gibt :count auslaufende Lizenz in den nächsten :threshold Tagen.|Es gibt :count auslaufende Lizenzen in den nächsten :threshold Tagen.',
    'link_to_update_password' => 'Klicken Sie bitte auf den folgenden Link zum Aktualisieren Ihres :web Passworts:',
    'login' => 'Benutzername:',
    'login_first_admin' => 'Melden Sie sich zu Ihrer neuen Snipe-IT-Installation mithilfe der unten stehenden Anmeldeinformationen an:',
    'low_inventory_alert' => 'Es gibt :count Artikel, der unter dem Minimum ist oder kurz davor ist.|Es gibt :count Artikel, die unter dem Minimum sind oder kurz davor sind.',
    'min_QTY' => 'Mindestmenge',
    'name' => 'Name',
    'new_item_checked' => 'Ein neuer Gegenstand wurde unter Ihrem Namen ausgecheckt. Details finden Sie weiter unten.',
    'notes' => 'Notizen',
    'password' => 'Passwort:',
    'password_reset' => 'Passwort zurücksetzen',
    'read_the_terms' => 'Bitte lesen Sie die nachfolgenden Nutzungsbedingungen.',
    'read_the_terms_and_click' => 'Bitte lesen Sie die Nutzungsbedingungen unten, und klicken Sie auf den Link am unteren Ende, um zu bestätigen, dass Sie die Nutzungsbedingungen gelesen und akzeptiert haben und das Asset erhalten haben.',
    'requested' => 'Angefordert:',
    'reset_link' => 'Ihr Link zum Zurücksetzen des Kennworts',
    'reset_password' => 'Klicken Sie hier, um Ihr Passwort zurückzusetzen:',
    'rights_reserved' => 'Alle Rechte vorbehalten.',
    'serial' => 'Seriennummer',
    'snipe_webhook_test' => 'Snipe-IT Integrationstest',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Zusammenfassung',
    'supplier' => 'Lieferant',
    'tag' => 'Kennzeichnung',
    'test_email' => 'Test E-Mail von Snipe-IT',
    'test_mail_text' => 'Dies ist ein Test von Snipe-IT-Asset-Management-System. Wenn Sie das erhalten haben, funktioniert das Senden von Mails :)',
    'the_following_item' => 'Der folgende Gegenstand wurde eingecheckt: ',
    'to_reset' => 'Zum Zurücksetzen Ihres :web Passwortes, füllen Sie bitte dieses Formular aus:',
    'type' => 'Typ',
    'upcoming-audits' => 'Es ist :count Asset vorhanden, für das innerhalb von :threshold Tagen ein Audit durchzuführen ist. |Es gibt :count Assets, für die innerhalb von :threshold Tagen Audits durchzuführen sind.',
    'user' => 'Benutzer',
    'username' => 'Benutzername',
    'unaccepted_asset_reminder' => 'Sie haben nicht akzeptierte Assets.',
    'welcome' => 'Wilkommen, :name',
    'welcome_to' => 'Willkommen bei :web!',
    'your_assets' => 'Ihre Assets anzeigen',
    'your_credentials' => 'Ihre Snipe-IT Anmeldedaten',
    'mail_sent' => 'Mail erfolgreich gesendet!',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/de-DE/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Zubehör zurückgenommen',
    'Accessory_Checkout_Notification' => 'Zubehör herausgegeben',
    'Asset_Checkin_Notification' => 'Asset zurückgenommen',
    'Asset_Checkout_Notification' => 'Asset herausgegeben',
    'Confirm_Accessory_Checkin' => 'Bestätigung einer Zubehör Rücknahme',
    'Confirm_Asset_Checkin' => 'Bestätigung einer Asset Rücknahme',
    'Confirm_accessory_delivery' => 'Bestätigung einer Zubehör Herausgabe',
    'Confirm_asset_delivery' => 'Bestätigung einer Asset Herausgabe',
    'Confirm_consumable_delivery' => 'Bestätigung einer Verbrauchsmaterial Herausgabe',
    'Confirm_license_delivery' => 'Bestätigung einer Lizenz Herausgabe',
    'Consumable_checkout_notification' => 'Verbrauchsmaterial herausgegeben',
    'Days' => 'Tage',
    'Expected_Checkin_Date' => 'Ihr ausgebuchtes Asset ist fällig zur Rückgabe am :date',
    'Expected_Checkin_Notification' => 'Erinnerung: :name Rückgabedatum nähert sich',
    'Expected_Checkin_Report' => 'Bericht über erwartete Asset Rückgaben',
    'Expiring_Assets_Report' => 'Bericht über ablaufende Gegenstände.',
    'Expiring_Licenses_Report' => 'Bericht über ablaufende Lizenzen.',
    'Item_Request_Canceled' => 'Gegenstands Anfrage abgebrochen',
    'Item_Requested' => 'Gegenstand angefordert',
    'License_Checkin_Notification' => 'Lizenz zurückgenommen',
    'License_Checkout_Notification' => 'Lizenz herausgegeben',
    'Low_Inventory_Report' => 'Bericht über niedrige Lagerbestände',
    'a_user_canceled' => 'Eine Geräte-Anfrage auf der Webseite wurde vom Benutzer abgebrochen',
    'a_user_requested' => 'Ein Benutzer hat ein Gerät auf der Webseite angefordert',
    'acceptance_asset_accepted' => 'Ein Benutzer hat einen Gegenstand akzeptiert',
    'acceptance_asset_declined' => 'Ein Benutzer hat einen Gegenstand abgelehnt',
    'accessory_name' => 'Zubehör Name',
    'additional_notes' => 'Zusätzliche Bemerkungen',
    'admin_has_created' => 'Ein Administrator hat auf der :web Webseite ein Konto für Sie erstellt.',
    'asset' => 'Asset',
    'asset_name' => 'Asset Name',
    'asset_requested' => 'Gegenstand angefordert',
    'asset_tag' => 'Asset Tag',
    'assets_warrantee_alert' => 'Die Garantie von :count Asset wird in :threshold Tagen auslaufen.|Die Garantie von :count Assets wird in :threshold Tagen auslaufen.',
    'assigned_to' => 'Zugewiesen an',
    'best_regards' => 'Grüße,',
    'canceled' => 'Abgebrochen',
    'checkin_date' => 'Rücknahmedatum',
    'checkout_date' => 'Herausgabedatum',
    'checkedout_from' => 'Herausgegeben von',
    'checkedin_from'  => 'Eingecheckt von',
    'checked_into' => 'Zurückgenommen in',
    'click_on_the_link_accessory' => 'Bitte klicken Sie auf den Link weiter unten, um den Erhalt des Zubehörs zu bestätigen.',
    'click_on_the_link_asset' => 'Bitte klicken Sie auf den Link weiter unten, um den Erhalt des Gegenstands zu bestätigen.',
    'click_to_confirm' => 'Bitte klicken Sie zum Bestätigen Ihres :web Kontos auf den folgenden Link:',
    'current_QTY' => 'Aktuelle Menge',
    'days' => 'Tage',
    'expecting_checkin_date' => 'Erwartetes Rückgabedatum',
    'expires' => 'Ablaufdatum',
    'hello' => 'Hallo',
    'hi' => 'Hallo',
    'i_have_read' => 'Ich habe die Nutzungsbedingungen gelesen und stimme diesen zu, und ich habe diesen Gegenstand erhalten.',
    'inventory_report' => 'Bestandsbericht',
    'item' => 'Gegenstand',
    'item_checked_reminder' => 'Dies ist eine Erinnerung daran, dass Sie derzeit :count Artikel ausgeliehen haben, die Sie weder angenommen noch abgelehnt haben. Klicken Sie bitte auf den untenstehenden Link, um diese entweder anzunehmen oder abzulehnen.',
    'license_expiring_alert' => 'Es gibt :count auslaufende Lizenz in den nächsten :threshold Tagen.|Es gibt :count auslaufende Lizenzen in den nächsten :threshold Tagen.',
    'link_to_update_password' => 'Klicken Sie bitte auf den folgenden Link zum Aktualisieren Ihres :web Passworts:',
    'login' => 'Benutzername:',
    'login_first_admin' => 'Melden Sie sich zu Ihrer neuen Snipe-IT-Installation mithilfe der unten stehenden Anmeldeinformationen an:',
    'low_inventory_alert' => 'Es gibt :count Artikel, der unter dem Minimum ist oder kurz davor ist.|Es gibt :count Artikel, die unter dem Minimum sind oder kurz davor sind.',
    'min_QTY' => 'Mindestmenge',
    'name' => 'Name',
    'new_item_checked' => 'Ein neuer Gegenstand wurde unter Ihrem Namen ausgecheckt. Details finden Sie weiter unten.',
    'notes' => 'Notizen',
    'password' => 'Passwort',
    'password_reset' => 'Passwort zurücksetzen',
    'read_the_terms' => 'Bitte lesen Sie die nachfolgenden Nutzungsbedingungen.',
    'read_the_terms_and_click' => 'Bitte lesen Sie die Nutzungsbedingungen unten, und klicken Sie auf den Link am unteren Ende, um zu bestätigen, dass Sie die Nutzungsbedingungen gelesen und akzeptiert haben und das Asset erhalten haben.',
    'requested' => 'Angefordert',
    'reset_link' => 'Ihr Link zum Zurücksetzen des Kennworts',
    'reset_password' => 'Klicken Sie hier, um Ihr Passwort zurückzusetzen:',
    'rights_reserved' => 'Alle Rechte vorbehalten.',
    'serial' => 'Seriennummer',
    'snipe_webhook_test' => 'Snipe-IT Integrationstest',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Zusammenfassung',
    'supplier' => 'Lieferant',
    'tag' => 'Kennzeichnung',
    'test_email' => 'Test E-Mail von Snipe-IT',
    'test_mail_text' => 'Dies ist ein Test des Snipe-IT Asset Management Systems. Wenn Sie das erhalten haben, funktioniert das Senden von Mails :)',
    'the_following_item' => 'Der folgende Gegenstand wurde eingecheckt: ',
    'to_reset' => 'Zum Zurücksetzen Ihres :web Passwortes, füllen Sie bitte dieses Formular aus:',
    'type' => 'Typ',
    'upcoming-audits' => 'Es ist :count Asset vorhanden, für das innerhalb von :threshold Tagen ein Audit durchzuführen ist. |Es gibt :count Assets, für die innerhalb von :threshold Tagen Audits durchzuführen sind.',
    'user' => 'Benutzer',
    'username' => 'Benutzername',
    'unaccepted_asset_reminder' => 'Sie haben nicht akzeptierte Assets.',
    'welcome' => 'Willkommen, :name',
    'welcome_to' => 'Willkommen bei :web!',
    'your_assets' => 'Ihre Assets anzeigen',
    'your_credentials' => 'Ihre Snipe-IT Anmeldedaten',
    'mail_sent' => 'Mail erfolgreich gesendet!',
];
